# Teal

![teal-logo](docs/teal-logo.svg)

(An intent of an) opinionated RESTful Flask for big applications.

In development...


Logo and some icons made by [Freepik](http://www.freepik.com) from
[Flaticon](https://www.flaticon.com/), licensed by
[CC 3.0 BY](http://creativecommons.org/licenses/by/3.0/).